@@ -131,9 +131,9 @@ class Test(unittest.TestCase):
         self.assertEqual("I look at a test case", t, "Didn't get correct text: {}".format(t))
         
     def test_can_get_background_steps(self):
-        st = self.g.get_backgroud_steps()
-        self.assertEqual(3, len(st), "Didn't get Background Steps")
-        self.assertEqual("that I am Logged into the application", st[0].text, "Unexpected step definition")
+        background = self.g.get_backgroud_steps()
+        self.assertEqual(3, len(background.get_steps()), "Didn't get Background Steps")
+        self.assertEqual("that I am Logged into the application", background.get_steps()[0].text, "Unexpected step definition")
         
     def test_can_generate_description(self):
         s1 = '''When I look at a test case
